# Na-hydrogen exchanger, based on 6 state transporter by Crampin and Smith 2006

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    fkc = 1e6
    # dissociation constants for A+B>C where Kd = k-/k+
    # K_H is given as pK_H. K_H = 10^(-pK_H)
    pK_H = 6.783
    K_H = pow(10, -pK_H)
    K_Na = 33.6 # [=] mM
    kp = [1.21e1, 7.33e-1] # [=] 1/s
    km = [3.29, 2.69] # [=] 1/s
    pKi = 6.464
    ni = 3.18
    Kd_pHi = pow(pow(10, -pKi), -ni)

    kf_1 =[kp[0], fkc*K_H, fkc, kp[1], fkc*K_Na, fkc]
    kr_1 =[km[0], fkc, fkc*K_Na, km[1], fkc, fkc*K_H]

    # pH_dependent reactions
    kf_pHi = fkc
    kr_pHi = kf_pHi*Kd_pHi
    kf_2 = [kf_pHi]*6
    kr_2 = [kr_pHi]*6

    # detailed bal? They said they did it already
    # kr_1[5] = np.product(kf_1)/(np.product(kr_1[0:4]))
    # kr_2[5] = np.product(kf_2)/(np.product(kr_2[0:4]))

    # total kf and kr
    kf = kf_1 #+ kf_2
    kr = kr_1 #+ kr_2
    k_kinetic = kf + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o']]*2 + [1]*6

    return (k_kinetic, N_cT, K_C, W)













